@@ -391,7 +391,6 @@ components=main
 : "${DEFAULT_DIST:=unstable}"
 : "${HAVE_QEMU:=yes}"
 : "${RUN_MA_SAME_TESTS:=yes}"
-: "${HAVE_PROOT:=yes}"
 # by default, use the mmdebstrap executable in the current directory
 : "${CMD:=./mmdebstrap}"
 
@@ -505,9 +504,6 @@ if [ "$HAVE_QEMU" = "yes" ]; then
 	if [ "$DEFAULT_DIST" != "oldstable" ]; then
 		pkgs="$pkgs,squashfs-tools-ng,genext2fs"
 	fi
-	if [ "$HAVE_PROOT" = "yes" ]; then
-		pkgs="$pkgs,proot"
-	fi
 	if [ ! -e ./mmdebstrap ]; then
 		pkgs="$pkgs,mmdebstrap"
 	fi
@@ -536,7 +532,7 @@ if [ "$HAVE_QEMU" = "yes" ]; then
 		--aptopt='Acquire::http::Dl-Limit "1000"' \
 		--aptopt='Acquire::https::Dl-Limit "1000"' \
 		--aptopt='Acquire::Retries "5"' \
-		$DEFAULT_DIST - "$mirror" > "$tmpdir/debian-chroot.tar"
+		"$DEFAULT_DIST" - "$mirror" > "$tmpdir/debian-chroot.tar"
 
 	cat << END > "$tmpdir/mmdebstrap.service"
 [Unit]
