@@ -39,7 +39,7 @@ case $ARCH in
 		;;
 	arm64)
 		MACHINE="type=virt,gic-version=host,accel=kvm"
-		CODE="/usr/share/AAVMF/AAVMF_CODE.fd,readonly"
+		CODE="/usr/share/AAVMF/AAVMF_CODE.fd"
 		QEMUARCH="aarch64"
 		;;
 	*) echo "qemu kvm not supported on $ARCH" >&2;;
@@ -47,7 +47,7 @@ esac
 
 # the path to debian-$DEFAULT_DIST.qcow must be absolute or otherwise qemu will
 # look for the path relative to debian-$DEFAULT_DIST-overlay.qcow
-qemu-img create -f qcow2 -b "$(realpath $cachedir)/debian-$DEFAULT_DIST.qcow" -F qcow2 "$tmpdir/debian-$DEFAULT_DIST-overlay.qcow"
+qemu-img create -f qcow2 -b "$(realpath "$cachedir")/debian-$DEFAULT_DIST.qcow" -F qcow2 "$tmpdir/debian-$DEFAULT_DIST-overlay.qcow"
 # to connect to serial use:
 #   minicom -D 'unix#/tmp/ttyS0'
 #
@@ -63,7 +63,7 @@ timeout --foreground 40m qemu-system-"$QEMUARCH" \
 	-serial unix:/tmp/ttyS0,server,nowait \
 	-serial unix:/tmp/ttyS1,server,nowait \
 	-net nic,model=virtio -net user \
-	-drive if=pflash,format=raw,unit=0,read-only,file="$CODE" \
+	-drive if=pflash,format=raw,unit=0,read-only=on,file="$CODE" \
 	-virtfs local,id=mmdebstrap,path="$(pwd)/shared",security_model=none,mount_tag=mmdebstrap \
 	-drive file="$tmpdir/debian-$DEFAULT_DIST-overlay.qcow",cache=unsafe,index=0,if=virtio \
 	>"$tmpdir/log" 2>&1 || ret=$?
